Platform bootstrap plugin for Drasi
This plugin provides the Platform bootstrap provider implementation for fetching initial data from a remote Drasi Query API service.
Example
use drasi_bootstrap_platform::PlatformBootstrapProvider;
// Using the builder
let provider = PlatformBootstrapProvider::builder()
.with_query_api_url("http://remote-drasi:8080")
.with_timeout_seconds(600)
.build()
.expect("Failed to create provider");
// Or using configuration
use drasi_lib::bootstrap::PlatformBootstrapConfig;
let config = PlatformBootstrapConfig {
query_api_url: Some("http://remote-drasi:8080".to_string()),
timeout_seconds: 600,
};
let provider = PlatformBootstrapProvider::new(config)
.expect("Failed to create provider");Re-exports
pub use platform::PlatformBootstrapProvider;pub use platform::PlatformBootstrapProviderBuilder;
Modules
- descriptor
- Plugin descriptor for the Platform bootstrap provider.
- platform
- Platform bootstrap provider for remote Drasi sources
Structs
- Platform
Bootstrap Config - Platform bootstrap provider configuration